pub type Result<T> = Result<T, ComdirectError>;Expand description
Result alias used by all public operations of this crate.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(ComdirectError),
}pub type Result<T> = Result<T, ComdirectError>;Result alias used by all public operations of this crate.
pub enum Result<T> {
Ok(T),
Err(ComdirectError),
}